/*
 * Copyright (C) 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */

package com.android.inputmethod.latin;

import android.inputmethodservice.Keyboard;
import android.inputmethodservice.Keyboard.Key;

import java.util.List;

abstract class KeyDetector {
    protected Keyboard mKeyboard;
    protected Key[] mKeys;

    protected boolean mProximityCorrectOn;
    protected int mProximityThresholdSquare;

    public Key[] setKeyboard(Keyboard keyboard) {
        if (keyboard == null)
            throw new NullPointerException();
        mKeyboard = keyboard;
        List<Key> keys = mKeyboard.getKeys();
        Key[] array = keys.toArray(new Key[keys.size()]);
        mKeys = array;
        return array;
    }

    public void setProximityCorrectionEnabled(boolean enabled) {
        mProximityCorrectOn = enabled;
    }

    public boolean isProximityCorrectionEnabled() {
        return mProximityCorrectOn;
    }

    public void setProximityThreshold(int threshold) {
        mProximityThresholdSquare = threshold * threshold;
    }

    abstract public int[] newCodeArray();

    abstract public int getKeyIndexAndNearbyCodes(int x, int y, int[] allKeys);
}